@@ -1,5 +1,4 @@
 use ratatui::{
-    backend::Backend,
     layout::{Constraint, Direction, Rect},
     terminal::Frame,
 };
@@ -27,7 +26,7 @@ fn top_app_and_bottom_split(rect: Rect) -> (Rect, Rect, Rect) {
 
 pub struct Layout<'a> {
     pub header: HeaderDetails<'a>,
-    pub children: Vec<Table<'a>>,
+    pub children: Vec<Table>,
     pub footer: HelpText,
 }
 
@@ -100,7 +99,7 @@ impl<'a> Layout<'a> {
         }
     }
 
-    pub fn render(&self, frame: &mut Frame<impl Backend>, rect: Rect, ui_offset: usize) {
+    pub fn render(&self, frame: &mut Frame, rect: Rect, ui_offset: usize) {
         let (top, app, bottom) = top_app_and_bottom_split(rect);
         let layout_slots = self.build_layout(app);
         for i in 0..layout_slots.len() {
